#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primes
version:              0.2.1.0
visibility:           public
id:                   primes-0.2.1.0-5dFqmFtEQZu8fMD7oOp1xA
key:                  primes-0.2.1.0-5dFqmFtEQZu8fMD7oOp1xA
license:              BSD-3-Clause
maintainer:           Sebastian Fischer
author:               Sebastian Fischer
stability:            experimental
homepage:             http://github.com/sebfisch/primes
synopsis:             Efficient, purely functional generation of prime numbers
description:
    This Haskell library provides an efficient lazy wheel sieve for
    prime generation inspired by /Lazy wheel sieves and spirals of/
    /primes/ by Colin Runciman and /The Genuine Sieve of Eratosthenes/
    by Melissa O'\''Neil.

category:             Algorithms, Numerical
abi:                  32a97a05b51cfd34e82708f90a96357d
exposed:              True
exposed-modules:      Data.Numbers.Primes
import-dirs:          /usr/lib/ghc-9.6.6/site-local/primes-0.2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/primes-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/primes-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primes
hs-libraries:         HSprimes-0.2.1.0-5dFqmFtEQZu8fMD7oOp1xA
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-primes/html/primes.haddock
haddock-html:         /usr/share/doc/haskell-primes/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

